QUCAT stands for QUantum Circuit Analyzer Tool. 
This open source python library provides standard analysis
tools for superconducting electronic circuits, built around 
at least one Josephson junction.

A user will first build a circuit programmatically or 
using our graphical user interface.
Working in the basis of normal modes, one can then compute normal mode 
frequencies, dissipation rates, anharmonicities, and cross-Kerr couplings.
These normal modes can also be visualized graphically.
Finally, one can compute the Hamiltonian of the circuit, for further
processing in QuTiP. 

See https://qucat.org/ for installation, documentation, tutorials and more.

![alt text](artwork/logo.png)

